function [ dx,dy] = correct_drift4( im1,im2, dXinit, dYinit, windowmax)
% correct_drift
%   This function returns a displacement that maximize correlation
% between two images, and the associated shifted (corrected for drift) 
% image.
%
% 
% INPUT 
%
% im1: the reference image
% im2 : the image to be corrected for drift.
% [dXinit, dYinit] : the initial guess
% windowmax : maximum range over which the correlation is computed
% window-2 should be larger than the max displacement
% 
% OUTPUT
%
% [dX,dY] : DX and DY are the x and y displacement providing the best match
% im2 can be adjusted with imref by doing
% [yim,xim]=meshgrid(1:size(imref,2),1:size(imref,1));
% im2=interp2(yim,xim,im1,yim-dy,xim-dx,'Linear',0);


[Nx, Ny]=size(im1);
xmin=windowmax;
xmax=Nx-windowmax;
ymin=windowmax;
ymax=Ny-windowmax;
% the reference image is the first one of the stack
imref=double(im1(xmin:xmax,ymin:ymax));
imref=imref-mean2(imref);
normref=sqrt(sum(sum(imref.^2)));
im=double(im2);
im=circshift(im,[dXinit dYinit]);
%[X,Y]=meshgrid(-windowmax:windowmax,-windowmax:windowmax);
%correl=zeros(2*windowmax+1,2*windowmax+1);
correl=zeros(2*windowmax+1,2*windowmax+1);
[X,Y]=meshgrid(-windowmax:windowmax,-windowmax:windowmax);
test=true;
window=0;
while (test & window<windowmax)
    window=window+1;
   %for i=1:(2*window+1)^2
    for ind1=(windowmax-window+1):(windowmax+window+1)
        for ind2=(windowmax-window+1):(windowmax+window+1)
            if correl(ind1,ind2)==0
                %[ind1,ind2]=ind2sub(size(correl),i);
                imtemp=circshift(im,[X(ind1,ind2) Y(ind1,ind2)]);
                imtemp=imtemp(windowmax:(Nx-windowmax),windowmax:(Ny-windowmax));
                imtemp=imtemp-mean2(imtemp);
                norm=sqrt(sum(sum(imtemp.^2)));
                correl(ind1,ind2)=sum(sum(imref.*imtemp))/norm/normref;
            end
        end
    end
   [indxmax,indymax]=find(correl==max(correl(:)));
   test=(indxmax==windowmax-window+1 | indxmax==windowmax+window+1 | indymax==windowmax-window+1 | indymax==windowmax+window+1);
end
if test==0
 [ind1,ind2]=find(correl>0);
 mesh(X(ind1,ind2),Y(ind1,ind2),correl(ind1,ind2))

 [bestfit,dx,dy]=find_max(X,Y,correl);
 dx=dx+dXinit;
 dy=dy+dYinit;
else
    dx=dXinit;
    dy=dYinit;
end

% [xim,yim]=meshgrid(1:Ny,1:Nx);
end

