function [bestfit,xmax,ymax ] = find_max( X,Y,R )
%
%   find the max of a 2 variables function by quadratic fitting
% around the pixel of max value (+/-win)
%  The original function must have one single max located at 
% a distance greater than win from the edge.
%
% INPUT :
% X, Y : matrices of the [x,y] coordinates
% R : function (same dimension as X and Y)
%
% OUTPUT :
% bestfit : the best quadratic approximation of R (same dimension)
% xmax, ymax : the [x,y] position of the max

win=1;
%mesh(X,Y,R);
[indxmax,indymax]=find(R==max(R(:)));


subX=X(indxmax-win:indxmax+win,indymax-win:indymax+win);
subY=Y(indxmax-win:indxmax+win,indymax-win:indymax+win);
subR=R(indxmax-win:indxmax+win,indymax-win:indymax+win);

fitobject = fit([subX(:),subY(:)],subR(:),'poly22');
bestfit=fitobject(X,Y);

coeff = coeffvalues(fitobject);
% l'extremum de la fonction a + b*x + c*y + d*x^2 + e*x*y + f*y^2 est:
% x = -(c e - 2 b f)/(e^2 - 4 d f); 
% y = (-2 c d + b e)/(-e^2 + 4 d f);
xmax=-(coeff(3)*coeff(5) - 2*coeff(2)*coeff(6))/(coeff(5)^2 - 4*coeff(4)*coeff(6));
ymax=(-2*coeff(3)*coeff(4) + coeff(2)*coeff(5))/(-coeff(5)^2 + 4*coeff(4)*coeff(6));

end

